==> haskell-hiedb-0.4.3.0-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hiedb
version:              0.4.3.0
visibility:           public
id:                   hiedb-0.4.3.0-Ly8C2l75ueqI5cGKIK4jpr
key:                  hiedb-0.4.3.0-Ly8C2l75ueqI5cGKIK4jpr
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  68afdae6ab35638e1ecea43da8ed8f4b
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hiedb
hs-libraries:         HShiedb-0.4.3.0-Ly8C2l75ueqI5cGKIK4jpr
depends:
    algebraic-graphs-0.7-vX25dFEwTRKBJzXAui15e
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    filepath-1.4.2.2 ghc-9.4.8 hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    lucid-2.11.20230408-HKe6Wv8xdWQzghUUMBQqJ mtl-2.2.2
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    sqlite-simple-0.4.19.0-KcDbg0O4BMIHp3L61SaiEJ
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hiedb-0.4.3.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hiedb
version:              0.4.3.0
visibility:           public
id:                   hiedb-0.4.3.0-GbWrJ2JFYWf3KewwEzZ3xf
key:                  hiedb-0.4.3.0-GbWrJ2JFYWf3KewwEzZ3xf
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  97639c81852cf516f75c710ae40fbe22
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hiedb
hs-libraries:         HShiedb-0.4.3.0-GbWrJ2JFYWf3KewwEzZ3xf
depends:
    algebraic-graphs-0.7-vX25dFEwTRKBJzXAui15e
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    filepath-1.4.2.2 ghc-9.4.8 hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    lucid-2.11.20230408-66ROsipHcNfKexFxphBHut mtl-2.2.2
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    sqlite-simple-0.4.19.0-KcDbg0O4BMIHp3L61SaiEJ
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
